#include <iostream.h>
#include <iomanip.h>
#include "poker.h"
#include "sort.h"

// does the current object have two pairs of cards with the same faces?
bool Hand::HasTwoPair() const {
	Hand h(*this);
	h.Sort();
	CardFace f1 = h.GetCard(1).GetFace();
	CardFace f2 = h.GetCard(2).GetFace();
	CardFace f3 = h.GetCard(3).GetFace();
	CardFace f4 = h.GetCard(4).GetFace();
	CardFace f5 = h.GetCard(5).GetFace();
	return (((f1 == f2) && (f3 == f4)) || ((f2 == f3) && (f4 == f5)));
}

// does the current object have a straight?
bool Hand::HasStraight() const {
	Hand h(*this);
	h.Sort();
	CardFace f1 = h.GetCard(1).GetFace();
	CardFace f2 = h.GetCard(2).GetFace();
	CardFace f3 = h.GetCard(3).GetFace();
	CardFace f4 = h.GetCard(4).GetFace();
	CardFace f5 = h.GetCard(5).GetFace();
	int diff1 = f5 - f4;
	int diff2 = f4 - f3;
	int diff3 = f3 - f2;
	int diff4 = f2 - f1;
	return ((diff1 == 1) && (diff2 == 1) && (diff3 == 1) && (diff4 == 1));
}

// does the current object represent a  full house?
bool Hand::HasFullHouse() const {
	Hand h(*this);
	h.Sort();
	CardFace f1 = h.GetCard(1).GetFace();
	CardFace f2 = h.GetCard(2).GetFace();
	CardFace f3 = h.GetCard(3).GetFace();
	CardFace f4 = h.GetCard(4).GetFace();
	CardFace f5 = h.GetCard(5).GetFace();
	return (((f1 == f2) && (f3 == f5)) || ((f1 == f3) && (f4 == f5)));
}

// does the current object represent four of a kind?
bool Hand::HasFourOfAKind() const {
	Hand h(*this);
	h.Sort();
	CardFace f1 = h.GetCard(1).GetFace();
	CardFace f2 = h.GetCard(2).GetFace();
	CardFace f3 = h.GetCard(3).GetFace();
	CardFace f4 = h.GetCard(4).GetFace();
	CardFace f5 = h.GetCard(5).GetFace();
	return ((f1 == f4) || (f2 == f5));

}

// display the five cards in hand h to the output stream
ostream& operator << (ostream &sout, const Hand &h) {
	for (int i = 1; i <= 5; i++) {
		sout << setfill(' ') << setw(4) << h.GetCard(i);
	}
	sout << endl;
	return sout;
}

// return true if hand's have same quality, otherwise return false
bool operator == (const Hand &h1, const Hand &h2) {
	return (h1.Quality() == h2.Quality());
}


// return true if h1's quality is less than h2's quality, otherwise
// return false
bool operator < (const Hand &h1, const Hand &h2) {
	return (h1.Quality() < h2.Quality());
}

// sort the five cards in the hand
void Hand::Sort() {
	SelectionSort(Cards, 5);
	return;
}
