//**************************************************************************
//
// Copyright (c) 1997.
//      Richard D. Irwin, Inc.
//
// This software may not be distributed further without permission from
// Richard D. Irwin, Inc.
//
// This software is distributed WITHOUT ANY WARRANTY. No claims are made
// as to its functionality or purpose.
//
// Author: Devon Lockwood
// Date: 1/30/97
// $Revision: 1.1 $
// $Name: $
//
//**************************************************************************
/* EzWindows Library Source File
   FILE:        triangle.cc
   AUTHORS:     James P. Cohoon and Jack W. Davidson
   EDITED BY:   Devon Lockwood
   Time-stamp:  <97/01/17 18:55:36 dcl3a>

   Description
   ===========
   The TriangleShape class provides the ability to draw
   triangles in an EzWindow.
*/
#include "triangle.h"


TriangleShape::TriangleShape(SimpleWindow   &iWindow,
                             const Position &iCenter, 
                             const color    &iColor,
                             float           iLength) 
                           : Shape(iWindow, iCenter, iColor), 
                             Length(iLength) {

}


float TriangleShape::GetLength() const {
	
   return Length;
}


void TriangleShape::Draw() {
   const float    SideLength    (GetLength  ());
   const Position TriangleCenter(GetPosition());
   
   // Compute c, distance from center of triangle to
   // the top vertex, and a, the distance from the center
   // to the base of the triangle
   float c(SideLength / (2.0 * cos(30 * Pi / 180.0)));
   float a(tan(30 * Pi / 180.0) * .5 * SideLength);

   // Create an array containing the positions of the
   // vertices of the triangle
   Position TrianglePoints[4] = {
      TriangleCenter + Position(0, -c),
      TriangleCenter + Position(-.5 * SideLength, a),
      TriangleCenter + Position( .5 * SideLength, a),
      TriangleCenter + Position(0, -c)
   };

   // Draw the triangle
   GetWindow().RenderPolygon(TrianglePoints, 4, GetColor());
}


void TriangleShape::SetSize(float iLength) {
	
    Length = iLength;
}



