//**************************************************************************//
//                                                                          //
// Copyright (c) 1997.                                                      //
//      Richard D. Irwin, Inc.                                              //
//                                                                          //
// This software may not be distributed further without permission from     //
// Richard D. Irwin, Inc.                                                   //
//                                                                          //
// This software is distributed WITHOUT ANY WARRANTY. No claims are made    //
// as to its functionality or purpose.                                      //
//                                                                          //
// Authors: James P. Cohoon and Jack W. Davidson                            //
// Date: 7/15/96                                                            //
// Version: 1.0b                                                            //
//                                                                          //
//**************************************************************************//

#include <iostream.h>
#include <stdlib.h>
#include "random.h"
#include "ryg.h"

// default RYG constructor
RYG::RYG() {
	Random x(1, 9);
	Random y(0, 9);
	Random z(0, 9);
	x.Randomize();
	y.Randomize();
	z.Randomize();
	SecretNumber.SetX(x.Draw());
	SecretNumber.SetY(y.Draw());
	SecretNumber.SetZ(z.Draw());
}

// Welcome(): display opening message
void RYG::Welcome() const {
	cout << "Welcome to the red-yellow-green game.\n"
	<< "A number between 100 and 999 has been chosen\n"
	<< "for you to guess.\n" << endl;
}

// Prompt(): request next guess
void RYG::Prompt() const {
	cout << "What is your guess? " << flush;
}

// Congratulations(): announce their success
void RYG::Congratulations() const {
	cout << "Congratulations on your win!";
}

// GoodBye(): tell player the answer and so long
void RYG::GoodBye() const {
	cout << "Better luck next time" << endl;
}
// Winner(): reports whether response is all greens
bool RYG::Winner(const Response &R) const {
	return R.GetGreen() == 3;
}

// Display(): announce reds, yellows, greens
void RYG::Display(const Guess &G, const Response &R)
const {
	int red = R.GetRed();
	int yellow = R.GetYellow();
	int green = R.GetGreen();
	cout << "Guess " << G << " corresponds to "
	 << red << " red "
	 << yellow << " yellow "
	 << green << " green "
	 << "\n" << endl;
}

// Green(): return number of green responses to guess
int RYG::Green(const Guess &G) const {
	int green = 0;
	if (G.GetDigit(1) == SecretNumber.GetX())
		++green;
	if (G.GetDigit(2) == SecretNumber.GetY())
		++green;
	if (G.GetDigit(3) == SecretNumber.GetZ())
		++green;
	return green;
}

// Red(): return number of red responses to guess
int RYG::Red(const Guess &G) const {
	int sx = SecretNumber.GetX();
	int sy = SecretNumber.GetY();
	int sz = SecretNumber.GetZ();
	int gx = G.GetDigit(1);
	int gy = G.GetDigit(2);
	int gz = G.GetDigit(3);

	int red = 0;
	if ((gx != sx) && (gx != sy) && (gx != sz))
		++red;
	if ((gy != sx) && (gy != sy) && (gy != sz))
		++red;
	if ((gz != sx) && (gz != sy) && (gz != sz))
		++red;
	return red;
}

// Yellow(): return number of yellow responses to guess
int RYG::Yellow(const Guess &G) const {
	return 3 - Green(G) - Red(G);
}

// Evaluate(): determine reds, yellows, and greens
Response RYG::Evaluate(const Guess &G) const {
	return Response(Red(G), Yellow(G), Green(G));
}



void RYG::Play() {
	Welcome();
	Prompt();
	while (UserInput.Update()) {
		UserFeedback = Evaluate(UserInput);
		if (Winner(UserFeedback)) {
			Congratulations();
			return;
		}
		else {
			Display(UserInput, UserFeedback);
			Prompt();
		}
	}
	GoodBye();
}


