#include <stdlib.h>
#include "random.h"
#include "deck.h"

// SetCard(): assign a specific value to ith card
void Deck::SetCard(int i, const Card &c) {
	if ((i >= 1) && (i <= 52))
		Cards[i-1] = c;
	else {
		cerr << "Bad deck reference" << endl;
		exit(1);
	}
}

// Deck(): initialize a canonical deck
Deck::Deck() {
	int p = 1;
	for (int i = 1; i <= 4; ++i) {
		CardSuit s;
		switch (i) {
			case 1: s = club; break;
			case 2: s = diamond; break;
			case 3: s = heart; break;
			case 4: s = spade; break;
		}
		for (int j = 1; j <= 13; ++j) {
			CardFace f;
			switch (j) {
				case 1: f = two; break;
				case 2: f = three; break;
				case 3: f = four; break;
				case 4: f = five; break;
				case 5: f = six; break;
				case 6: f = seven; break;
				case 7: f = eight; break;
				case 8: f = nine; break;
				case 9: f = ten; break;
				case 10: f = jack; break;
				case 11: f = queen; break;
				case 12: f = king; break;
				case 13: f = ace; break;
			}
			Card c(f, s);
			SetCard(p, c);
			++p;
		}
	}
}

// GetCard(): return value of ith card
Card Deck::GetCard(int i) const {
	if ((i >= 1) && (i <= 52))
		return Cards[i-1];
	else {
		cerr << "Bad deck reference" << endl;
		exit(1);
	}
}

// SwapCards(): swap ith and jth cards
void Deck::SwapCards(int i, int j) {
	Card ci = GetCard(i);
	Card cj = GetCard(j);
	SetCard(i, cj);
	SetCard(j, ci);
}

// Shuffle(): put deck in random order
void Deck::Shuffle() {
	for (int i = 1; i <= 52; ++i) {
		Random r(i,52);
		r.Randomize();
		int j = r.Draw();
		SwapCards(i, j);
	}
}


