//**************************************************************************//
//                                                                          //
// Copyright (c) 1997.                                                      //
//      Richard D. Irwin, Inc.                                              //
//                                                                          //
// This software may not be distributed further without permission from     //
// Richard D. Irwin, Inc.                                                   //
//                                                                          //
// This software is distributed WITHOUT ANY WARRANTY. No claims are made    //
// as to its functionality or purpose.                                      //
//                                                                          //
// Authors: James P. Cohoon and Jack W. Davidson                            //
// Date: 7/15/96                                                            //
// Version: 1.0b                                                            //
//                                                                          //
//**************************************************************************//

// plays the puzzle search game

#include <fstream.h>

#include <string.h> // your compiler may call this cstring or cstring.h
#include "bool.h"   // if your compiler has a bool type comment out this line

const int MaxColumns = 20;
const int MaxRows = 20;

// prototypes
void PuzzleSearch(const char T[][MaxColumns], int r, int c, const char Word[]);
bool CheckWord(const char T[][MaxColumns], int i, int j, const char Word[], int RowOffset, int ColOffset);

// main(): manage play of puzzle search game
int main() {
	char S[MaxColumns];

	cout << "Enter puzzle table file name: " << flush;
	cin >> S;

	ifstream fin(S);

	char Table[MaxRows][MaxColumns];

	int n;
	int m ;
	for (n = 0; fin >> S; ++n) {
		m = strlen(S);
		for (int i = 0; i < m; ++i) {
			Table[n+1][i+1] = S[i];
		}
		Table[n+1][0] = Table[n+1][m+1] = ' ';
		Table[n+1][m+2] = '\0';
	}

	for (int i = 0; i <= m+1; ++i) {
		Table[0][i] = Table[n+1][i] = ' ';
	}
	Table[0][m+2] = Table[n+1][m+2] = '\0';

	for (int j = 0; j <= n+1; ++j) {
		cout << Table[j]  << endl;
	}

	cout << "Enter your puzzle search word: " << flush;

	while (cin >> S) {
		cout << endl;

		PuzzleSearch(Table, n, m, S);

		cout << endl;
		cout << "Enter your next search word: " << flush;
	}

	return 0;
}



// PuzzleSearch(): look for Word in T
void PuzzleSearch(const char T[][MaxColumns],
int r, int c, const char Word[]) {

	for (int i = 1; i <= r; ++i) {
		for (int j = 1; j <= c; ++j) {
			if (CheckWord(T, i, j, Word, 0, 1)) {
				cout << Word << " is at " << i << ", " << j
				<< " going horizontally right" << endl;
				return;
			}
			else if (CheckWord(T, i, j, Word, 0, -1)) {
				cout << Word << " is at " << i << ", " << j
				<< " going horizontally left" << endl;
				return;
			}
			else if (CheckWord(T, i, j, Word, 1, 0)) {
				cout << Word << " is at " << i << ", " << j
				<< " going vertically down" << endl;
				return;
			}
			else if (CheckWord(T, i, j, Word, -1, 0)) {
				cout << Word << " is at " << i << ", " << j
				<< " going vertically up" << endl;
				return;
			}
			else if (CheckWord(T, i, j, Word, 1, 1)) {
				cout << Word << " is at " << i << ", " << j
				<< " going diagonally right and down"
				<< endl;
				return;
			}
			else if (CheckWord(T, i, j, Word, 1, -1)) {
				cout << Word << " is at " << i << ", " << j
				<< " going diagonally left and down"
				<< endl;
				return;
			}
			else if (CheckWord(T, i, j, Word, -1, 1)) {
				cout << Word << " is at " << i << ", " << j
				<< " going diagonally right and up"
				<< endl;
				return;
			}
			else if (CheckWord(T, i, j, Word, -1, -1)) {
				cout << Word << " is at " << i << ", " << j
				<< " going diagonally left and up"
				<< endl;
				return;
			}
		}
	}

	cout << Word << " is not in the Puzzle" << endl;
	return;
}

// CheckWord(): look for Word in T starting at [i][j]
// changing row value by RowOffset and column value by
// ColOffset
bool CheckWord(const char T[][MaxColumns], int i,
int j, const char Word[], int RowOffset,
int ColOffset) {
	int Length = strlen(Word);
	int row = i;
	int col = j;
	for (int k = 0; k < Length; ++k) {
		if (Word[k] != T[row][col])
			return false;
		else {
			row += RowOffset;
			col += ColOffset;
		}
	}
	return true;
}



