//**************************************************************************//
//                                                                          //
// Copyright (c) 1997.                                                      //
//      Richard D. Irwin, Inc.                                              //
//                                                                          //
// This software may not be distributed further without permission from     //
// Richard D. Irwin, Inc.                                                   //
//                                                                          //
// This software is distributed WITHOUT ANY WARRANTY. No claims are made    //
// as to its functionality or purpose.                                      //
//                                                                          //
// Authors: James P. Cohoon and Jack W. Davidson                            //
// Date: 7/15/96                                                            //
// Version: 1.0b                                                            //
//                                                                          //
//**************************************************************************//

#ifndef SLIST_H
#define SLIST_H

#ifdef USING_CC
#include "bool.h"
#endif

#include <assert.h>
#include <iostream.h>
template <class T> class SeqItem{
	protected:
		// default constructor
		SeqItem(const T &Val, SeqItem *Succ)
		 : ItemValue(Val), Successor(Succ) {
			// no code needed
		};
	private:
		T ItemValue;        // element value
		SeqItem *Successor; // pointer to next element
	friend class SeqList<T>;
	friend class SeqElement<T>;
};

template <class T> class SeqList {
	public:
		// default constructor
		SeqList();
		// destructor
		~SeqList();
		// mutator to add item to list
		void Add(const T &NewValue);
		// mutator to remove item from list
		T Remove();
		// mutator to remove all elements from list
		void RemoveAll();
		// inspector of first value in list
		T First() const;
		// inspector of number of elements in list
		int Size() const;
		// method to display list
		void Insert(ostream &sout) const;
		// copy constructor
		SeqList(const SeqList &T);
		// assignment
		SeqList& operator=(const SeqList &T);
	private:
		SeqItem<T> *Front;  // pointer to first element
		SeqItem<T> *Rear;   // pointer to last element
		int ListLength;     // number of elements
	friend class SeqElement<T>;
};

template <class T> class SeqElement {
	public:
		// default constructor
		SeqElement(SeqList<T> &L);
		// iterator operator for next element in list
		void operator++();
		// inspector for value of current element in list
		T operator()() const;
		// mutator for value of current element in list
		void operator=(const T &NewListValue);
		// method to determine if current element is first
		bool IsFirst() const;
		// method to determine if current element is last
		bool IsLast() const;
		// method to associate iterator with first element
		void ResetToFront();
		// cast to determine whether list is empty
		operator bool() const;
	private:
		SeqItem<T> *ItemPtr;								// pointer to current element
		SeqList<T> &TheList;								// list being iterated
	friend class SeqList<T>;
};


// default SeqList constructor
template <class T> SeqList<T>::SeqList()
 : Front(0), Rear(0), ListLength(0) { // no code needed
}
// SeqList destructor
template <class T> SeqList<T>::~SeqList() {
	RemoveAll();
}
// Size(): return size of list
template<class T> int SeqList<T>::Size() const {
	return ListLength;
}
// Front(): return first element in list
template<class T> T SeqList<T>::First() const {
	assert(Size() != 0);
	return Front->ItemValue;
}
// Insert(): display list
template<class T>
void SeqList<T>::Insert(ostream &sout) const {
	SeqItem<T> *Ptr;    
	for (Ptr = Front; Ptr; Ptr = Ptr->Successor)
		sout << " " << Ptr->ItemValue;
}
// Add(): add value to end of list
template<class T> void SeqList<T>::Add(const T &Val) {
	SeqItem<T> *Ptr = new SeqItem<T>(Val,0);
	assert(Ptr);
	if (Size() == 0)
		Front = Ptr;
	else
		Rear->Successor = Ptr;
	Rear = Ptr;
	++ListLength;
}
// Remove(): remove value from front of the list
template<class T> T SeqList<T>::Remove() {
	assert(Front);
	SeqItem<T> *Ptr = Front->Successor;
	T ReturnValue = Front->ItemValue;
	delete Front;
	Front = Ptr;
	if (Front == 0)
		Rear = 0;
	--ListLength;
	return ReturnValue;
}
// RemoveAll(): purge list
template<class T> void SeqList<T>::RemoveAll() {
	SeqItem<T> *Ptr = Front;
	while ( Ptr ) {
		SeqItem<T> *Next = Ptr->Successor;
		delete Ptr;
		Ptr = Next;
	}
	Front = Rear = 0;
	ListLength = 0;
}

// SeqElement(): constructor
template <class T>
SeqElement<T>::SeqElement(SeqList<T> &L)
:  ItemPtr(L.Front), TheList(L) {
	// no code needed
}

// ++: SeqElement() successor iterator
template <class T> void SeqElement<T>::operator++() {
	assert(ItemPtr != 0);
	ItemPtr = ItemPtr->Successor;
}

// (): SeqElement() data inspector
template <class T> T SeqElement<T>::operator()() const{
	assert(ItemPtr != 0);
	return ItemPtr->ItemValue;
}

// =: SeqElement() data mutator
template <class T> void SeqElement<T>::operator=(
const T &NewListValue) {
	assert(ItemPtr != 0);
	ItemPtr->ItemValue = NewListValue;
}

// bool: indicates whether there is a list element
template <class T> SeqElement<T>::operator bool()
const {
	return ItemPtr != 0;
}

// IsFirst(): indicates whether first element
template <class T> bool SeqElement<T>::IsFirst() const{
	assert(ItemPtr != 0);
	return TheList.Front == ItemPtr;
}

// IsLast(): indicates whether last element
template <class T> bool SeqElement<T>::IsLast() const {
	assert(ItemPtr != 0);
	return ItemPtr->Successor == 0;
}

// ResetToFront(): associate with first element
template <class T> void SeqElement<T>::ResetToFront() {
	ItemPtr = TheList.Front;
}

// <<: overload insertions for list element
template <class T>ostream& operator<<(ostream &sout,
const SeqElement<T> &a) {
	return sout << a();
}

#endif


